context("utf8_valid")

test_that("'as_utf8' errors on latin1 declared to be UTF-8", {
    x <- c("a", "b", "the command of her beauty, and her \xa320,000", "d")
    Encoding(x) <- "UTF-8"

    expect_equal(utf8_valid(x), c(TRUE, TRUE, FALSE, TRUE))
    expect_error(as_utf8(x), "argument entry 3 is marked as \"UTF-8\" but contains an invalid byte in position 36 (\\xa3)", fixed = TRUE)
})


test_that("utf8_valid errors on invalid UTF-8", {
    x <- c("a", "b", "c", "d", intToUtf8(0x00200000))
    Encoding(x) <- "UTF-8"

    expect_equal(utf8_valid(x), c(TRUE, TRUE, TRUE, TRUE, FALSE))
    expect_error(as_utf8(x), "argument entry 5 is marked as \"UTF-8\" but contains an invalid byte in position 1 (\\xf8)", fixed = TRUE)
})


test_that("utf8_valid passes on valid UTF-8 in bytes encoding", {
    x <- "hello\u2002"
    Encoding(x) <- "bytes"
    expect_equal(utf8_valid(x), TRUE)

    y <- x
    Encoding(y) <- "UTF-8"
    expect_equal(as_utf8(x), enc2utf8(y))
})


test_that("utf8_valid passes on valid ASCII in unknown encoding", {
    x <- "world"
    expect_equal(utf8_valid(x), TRUE)
    expect_equal(as_utf8(x), enc2utf8(x))
})


test_that("utf8_valid errors on invalid UTF8 in bytes encoding", {
    x <- paste0("hello", intToUtf8(0xfffffff))
    Encoding(x) <- "bytes"
    expect_equal(utf8_valid(x), FALSE)
    expect_error(as_utf8(x), "argument entry 1 cannot be converted from \"bytes\" to \"UTF-8\"; it contains an invalid byte in position 6 (\\xfc)", fixed = TRUE)
})
